import { EditorView, Command, KeyBinding, Panel } from "@codemirror/view";
import { EditorState, StateEffect, SelectionRange, StateCommand, Extension, Text } from "@codemirror/state";
import { SearchCursor } from "./cursor";
import { RegExpCursor } from "./regexp";
import { gotoLine } from "./goto-line";
import { selectNextOccurrence } from "./selection-match";
export { highlightSelectionMatches } from "./selection-match";
export { SearchCursor, RegExpCursor, gotoLine, selectNextOccurrence };
interface SearchConfig {
    top?: boolean;
    caseSensitive?: boolean;
    literal?: boolean;
    wholeWord?: boolean;
    regexp?: boolean;
    createPanel?: (view: EditorView) => Panel;
    scrollToMatch?: (range: SelectionRange, view: EditorView) => StateEffect<unknown>;
}
export declare function search(config?: SearchConfig): Extension;
export declare class SearchQuery {
    readonly search: string;
    readonly caseSensitive: boolean;
    readonly literal: boolean;
    readonly regexp: boolean;
    readonly replace: string;
    readonly valid: boolean;
    readonly wholeWord: boolean;
    readonly unquoted: string;
    constructor(config: {
        search: string;
        caseSensitive?: boolean;
        literal?: boolean;
        regexp?: boolean;
        replace?: string;
        wholeWord?: boolean;
    });
    unquote(text: string): string;
    eq(other: SearchQuery): boolean;
    create(): QueryType;
    getCursor(state: EditorState | Text, from?: number, to?: number): Iterator<{
        from: number;
        to: number;
    }>;
}
declare type SearchResult = typeof SearchCursor.prototype.value;
declare abstract class QueryType<Result extends SearchResult = SearchResult> {
    readonly spec: SearchQuery;
    constructor(spec: SearchQuery);
    abstract nextMatch(state: EditorState, curFrom: number, curTo: number): Result | null;
    abstract prevMatch(state: EditorState, curFrom: number, curTo: number): Result | null;
    abstract getReplacement(result: Result): string;
    abstract matchAll(state: EditorState, limit: number): readonly Result[] | null;
    abstract highlight(state: EditorState, from: number, to: number, add: (from: number, to: number) => void): void;
}
export declare const setSearchQuery: import("@codemirror/state").StateEffectType<SearchQuery>;
export declare function getSearchQuery(state: EditorState): SearchQuery;
export declare function searchPanelOpen(state: EditorState): boolean;
export declare const findNext: Command;
export declare const findPrevious: Command;
export declare const selectMatches: Command;
export declare const selectSelectionMatches: StateCommand;
export declare const replaceNext: Command;
export declare const replaceAll: Command;
export declare const openSearchPanel: Command;
export declare const closeSearchPanel: Command;
export declare const searchKeymap: readonly KeyBinding[];
